import { RabbitSubscribe } from '@golevelup/nestjs-rabbitmq';
import { Inject } from '@nestjs/common';
import { WINSTON_MODULE_PROVIDER } from 'nest-winston';
import { Logger } from 'winston';
import loggerOptions from '../logger.options';
import { level } from '../level.enum';

export class AuthMessageHandler {
  constructor(
    @Inject(WINSTON_MODULE_PROVIDER) private readonly logger: Logger,
  ) {}

  @RabbitSubscribe({
    name: 'loggingAuthCreatedCrit',
  })
  public async authCreatedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.crit, 'critical', 'created'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthDeletedCrit',
  })
  public async authDeletedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.crit, 'critical', 'deleted'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthReadWarning',
  })
  public async authReadWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.warning, 'warning', 'read'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthUsernameCreatedWarning',
  })
  public async authUsernameCreatedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.warning, 'warning', 'username-created'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthUsernameDeletedWarning',
  })
  public async authUsernameDeletedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.warning, 'warning', 'username-deleted'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthUsernameReadWarning',
  })
  public async authUsernameReadWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.warning, 'warning', 'username-read'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthPasswordUpdatedWarning',
  })
  public async authPasswordUpdatedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.warning, 'warning', 'password-updated'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthUsernameUpdatedWarning',
  })
  public async authUsernameUpdatedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.warning, 'warning', 'username-updated'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAuthHealthCrit',
  })
  public async authHealthCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('auth', level.crit, 'critical', 'health'),
    );
    this.logger.crit(JSON.parse(message));
  }
}
