import { RabbitSubscribe } from '@golevelup/nestjs-rabbitmq';
import { Inject } from '@nestjs/common';
import { WINSTON_MODULE_PROVIDER } from 'nest-winston';
import { Logger } from 'winston';
import loggerOptions from '../logger.options';
import { level } from '../level.enum';

export class ConfigurationMessageHandler {
  constructor(
    @Inject(WINSTON_MODULE_PROVIDER) private readonly logger: Logger,
  ) {}

  @RabbitSubscribe({
    name: 'loggingConfigurationCreatedInfo',
  })
  public async configurationCreatedInfoHandler(message: string) {
    this.logger.configure(
      loggerOptions('configuration', level.info, 'info', 'created'),
    );
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingConfigurationCreatedWarning',
  })
  public async configurationCreatedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('configuration', level.warning, 'warning', 'created'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingConfigurationCreatedCrit',
  })
  public async configurationCreatedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('configuration', level.crit, 'critical', 'created'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingConfigurationDeletedInfo',
  })
  public async configurationDeletedInfoHandler(message: string) {
    this.logger.configure(
      loggerOptions('configuration', level.info, 'info', 'deleted'),
    );
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingConfigurationDeletedCrit',
  })
  public async configurationDeletedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('configuration', level.crit, 'critical', 'deleted'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingConfigurationReadWarning',
  })
  public async configurationReadWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('configuration', level.warning, 'warning', 'read'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingConfigurationUpdatedInfo',
  })
  public async configurationUpdatedInfoHandler(message: string) {
    this.logger.configure(
      loggerOptions('configuration', level.info, 'info', 'updated'),
    );
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingConfigurationUpdatedCrit',
  })
  public async configurationUpdatedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('configuration', level.crit, 'critical', 'updated'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingConfigurationHealthCrit',
  })
  public async configurationHealthCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('configuration', level.crit, 'critical', 'health'),
    );
    this.logger.crit(JSON.parse(message));
  }
}
