import { RabbitSubscribe } from '@golevelup/nestjs-rabbitmq';
import { Inject } from '@nestjs/common';
import { WINSTON_MODULE_PROVIDER } from 'nest-winston';
import { Logger } from 'winston';
import loggerOptions from '../logger.options';
import { level } from '../level.enum';

export class TerritoryMessageHandler {
  constructor(
    @Inject(WINSTON_MODULE_PROVIDER) private readonly logger: Logger,
  ) {}

  @RabbitSubscribe({
    name: 'loggingTerritoryCreatedInfo',
  })
  public async territoryCreatedInfoHandler(message: string) {
    this.logger.configure(
      loggerOptions('territory', level.info, 'info', 'created'),
    );
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingTerritoryCreatedWarning',
  })
  public async territoryCreatedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('territory', level.warning, 'warning', 'created'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingTerritoryCreatedCrit',
  })
  public async territoryCreatedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('territory', level.crit, 'critical', 'created'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingTerritoryDeletedInfo',
  })
  public async territoryDeletedInfoHandler(message: string) {
    this.logger.configure(
      loggerOptions('territory', level.info, 'info', 'deleted'),
    );
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingTerritoryDeletedCrit',
  })
  public async territoryDeletedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('territory', level.crit, 'critical', 'deleted'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingTerritoryReadWarning',
  })
  public async territoryReadWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('territory', level.warning, 'warning', 'read'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingTerritoryUpdatedInfo',
  })
  public async territoryUpdatedInfoHandler(message: string) {
    this.logger.configure(
      loggerOptions('territory', level.info, 'info', 'updated'),
    );
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingTerritoryUpdatedCrit',
  })
  public async territoryUpdatedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('territory', level.crit, 'critical', 'updated'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingTerritoryHealthCrit',
  })
  public async territoryHealthCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('territory', level.crit, 'critical', 'health'),
    );
    this.logger.crit(JSON.parse(message));
  }
}
