import { RabbitSubscribe } from '@golevelup/nestjs-rabbitmq';
import { Inject } from '@nestjs/common';
import { WINSTON_MODULE_PROVIDER } from 'nest-winston';
import { Logger } from 'winston';
import loggerOptions from '../logger.options';
import { level } from '../level.enum';

export class UserMessageHandler {
  constructor(
    @Inject(WINSTON_MODULE_PROVIDER) private readonly logger: Logger,
  ) {}

  @RabbitSubscribe({
    name: 'loggingUserCreatedInfo',
  })
  public async userCreatedInfoHandler(message: string) {
    this.logger.configure(loggerOptions('user', level.info, 'info', 'created'));
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingUserCreatedWarning',
  })
  public async userCreatedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('user', level.warning, 'warning', 'created'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingUserCreatedCrit',
  })
  public async userCreatedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('user', level.crit, 'critical', 'created'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingUserDeletedInfo',
  })
  public async userDeletedInfoHandler(message: string) {
    this.logger.configure(loggerOptions('user', level.info, 'info', 'deleted'));
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingUserDeletedCrit',
  })
  public async userDeletedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('user', level.crit, 'critical', 'deleted'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingUserReadWarning',
  })
  public async userReadWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('user', level.warning, 'warning', 'read'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingUserUpdatedInfo',
  })
  public async userUpdatedInfoHandler(message: string) {
    this.logger.configure(loggerOptions('user', level.info, 'info', 'updated'));
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingUserUpdatedCrit',
  })
  public async userUpdatedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('user', level.crit, 'critical', 'updated'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingUserHealthCrit',
  })
  public async userHealthCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('user', level.crit, 'critical', 'health'),
    );
    this.logger.crit(JSON.parse(message));
  }
}
