import { Module, Provider } from '@nestjs/common';
import { WinstonModule } from 'nest-winston';
import * as winston from 'winston';
import { AdMessageHandler } from './interface/message-handlers/ad.message-handler';
import { AuthMessageHandler } from './interface/message-handlers/auth.message-handler';
import { UserMessageHandler } from './interface/message-handlers/user.message-handler';
import { ConfigurationMessageHandler } from './interface/message-handlers/configuration.message-handler';
import { MatcherMessageHandler } from './interface/message-handlers/matcher.message-handler';
import { TerritoryMessageHandler } from './interface/message-handlers/territory.message-handler';
import { GatewayApiMessageHandler } from './interface/message-handlers/gateway-api.message-handler';
import { AdminApiMessageHandler } from './interface/message-handlers/admin-api.message-handler';
import { LoggerMessageHandler } from './interface/message-handlers/logger.message-handler';

const messageHandlers: Provider[] = [
  AdMessageHandler,
  AuthMessageHandler,
  UserMessageHandler,
  ConfigurationMessageHandler,
  LoggerMessageHandler,
  MatcherMessageHandler,
  TerritoryMessageHandler,
  GatewayApiMessageHandler,
  AdminApiMessageHandler,
];

@Module({
  imports: [
    WinstonModule.forRoot({
      levels: winston.config.syslog.levels,
      transports: [],
    }),
  ],
  providers: [...messageHandlers],
  exports: [],
})
export class LoggerModule {}
