import { Module, Provider } from '@nestjs/common';
import { MESSAGE_PUBLISHER } from './messager.di-tokens';
import {
  MessageBrokerModule,
  MessageBrokerModuleOptions,
  MessageBrokerPublisher,
} from '@mobicoop/message-broker-module';
import { ConfigModule, ConfigService } from '@nestjs/config';

const imports = [
  MessageBrokerModule.forRootAsync({
    imports: [ConfigModule],
    inject: [ConfigService],
    useFactory: async (
      configService: ConfigService,
    ): Promise<MessageBrokerModuleOptions> => ({
      uri: configService.get<string>('MESSAGE_BROKER_URI'),
      exchange: configService.get<string>('MESSAGE_BROKER_EXCHANGE'),
      name: 'logger',
      handlers: {
        loggingGatewayApiHealthCrit: {
          routingKey: 'logging.gateway-api.health.crit',
          queue: 'logging-gateway-api-health-crit',
        },
        loggingAdminApiHealthCrit: {
          routingKey: 'logging.admin-api.health.crit',
          queue: 'logging-admin-api-health-crit',
        },
        loggingAdCreatedInfo: {
          routingKey: 'logging.ad.created.info',
          queue: 'logging-ad-created-info',
        },
        loggingAdCreatedWarning: {
          routingKey: 'logging.ad.created.warning',
          queue: 'logging-ad-created-warning',
        },
        loggingAdCreatedCrit: {
          routingKey: 'logging.ad.created.crit',
          queue: 'logging-ad-created-crit',
        },
        loggingAdDeletedInfo: {
          routingKey: 'logging.ad.deleted.info',
          queue: 'logging-ad-deleted-info',
        },
        loggingAdDeletedCrit: {
          routingKey: 'logging.ad.deleted.crit',
          queue: 'logging-ad-deleted-crit',
        },
        loggingAdReadWarning: {
          routingKey: 'logging.ad.read.warning',
          queue: 'logging-ad-read-warning',
        },
        loggingAdUpdatedInfo: {
          routingKey: 'logging.ad.updated.info',
          queue: 'logging-ad-updated-info',
        },
        loggingAdUpdatedCrit: {
          routingKey: 'logging.ad.updated.crit',
          queue: 'logging-ad-updated-crit',
        },
        loggingAdHealthCrit: {
          routingKey: 'logging.ad.health.crit',
          queue: 'logging-ad-health-crit',
        },
        loggingAuthCreatedCrit: {
          routingKey: 'logging.auth.created.crit',
          queue: 'logging-auth-created-crit',
        },
        loggingAuthDeletedCrit: {
          routingKey: 'logging.auth.deleted.crit',
          queue: 'logging-auth-deleted-crit',
        },
        loggingAuthReadWarning: {
          routingKey: 'logging.auth.read.warning',
          queue: 'logging-auth-read-warning',
        },
        loggingAuthUsernameCreatedWarning: {
          routingKey: 'logging.auth.username.created.warning',
          queue: 'logging-auth-username-created-warning',
        },
        loggingAuthUsernameDeletedWarning: {
          routingKey: 'logging.auth.username.deleted.warning',
          queue: 'logging-auth-username-deleted-warning',
        },
        loggingAuthUsernameReadWarning: {
          routingKey: 'logging.auth.username.read.warning',
          queue: 'logging-auth-username-read-warning',
        },
        loggingAuthPasswordUpdatedWarning: {
          routingKey: 'logging.auth.password.updated.warning',
          queue: 'logging-auth-password-updated-warning',
        },
        loggingAuthUsernameUpdatedWarning: {
          routingKey: 'logging.auth.username.updated.warning',
          queue: 'logging-auth-username-updated-warning',
        },
        loggingAuthHealthCrit: {
          routingKey: 'logging.auth.health.crit',
          queue: 'logging-auth-health-crit',
        },
        loggingConfigurationCreatedInfo: {
          routingKey: 'logging.configuration.created.info',
          queue: 'logging-configuration-created-info',
        },
        loggingConfigurationCreatedWarning: {
          routingKey: 'logging.configuration.created.warning',
          queue: 'logging-configuration-created-warning',
        },
        loggingConfigurationCreatedCrit: {
          routingKey: 'logging.configuration.created.crit',
          queue: 'logging-configuration-created-crit',
        },
        loggingConfigurationDeletedInfo: {
          routingKey: 'logging.configuration.deleted.info',
          queue: 'logging-configuration-deleted-info',
        },
        loggingConfigurationDeletedCrit: {
          routingKey: 'logging.configuration.deleted.crit',
          queue: 'logging-configuration-deleted-crit',
        },
        loggingConfigurationReadWarning: {
          routingKey: 'logging.configuration.read.warning',
          queue: 'logging-configuration-read-warning',
        },
        loggingConfigurationUpdatedInfo: {
          routingKey: 'logging.configuration.updated.info',
          queue: 'logging-configuration-updated-info',
        },
        loggingConfigurationUpdatedCrit: {
          routingKey: 'logging.configuration.updated.crit',
          queue: 'logging-configuration-updated-crit',
        },
        loggingConfigurationHealthCrit: {
          routingKey: 'logging.configuration.health.crit',
          queue: 'logging-configuration-health-crit',
        },
        loggingLoggerHealthCrit: {
          routingKey: 'logging.logger.health.crit',
          queue: 'logging-logger-health-crit',
        },
        loggingMatcherAdCrit: {
          routingKey: 'logging.matcher.ad.crit',
          queue: 'logging-matcher-ad-crit',
        },
        loggingMatcherMatchCrit: {
          routingKey: 'logging.matcher.match.crit',
          queue: 'logging-matcher-match-crit',
        },
        loggingTerritoryCreatedInfo: {
          routingKey: 'logging.territory.created.info',
          queue: 'logging-territory-created-info',
        },
        loggingTerritoryCreatedWarning: {
          routingKey: 'logging.territory.created.warning',
          queue: 'logging-territory-created-warning',
        },
        loggingTerritoryCreatedCrit: {
          routingKey: 'logging.territory.created.crit',
          queue: 'logging-territory-created-crit',
        },
        loggingTerritoryDeletedInfo: {
          routingKey: 'logging.territory.deleted.info',
          queue: 'logging-territory-deleted-info',
        },
        loggingTerritoryDeletedCrit: {
          routingKey: 'logging.territory.deleted.crit',
          queue: 'logging-territory-deleted-crit',
        },
        loggingTerritoryReadWarning: {
          routingKey: 'logging.territory.read.warning',
          queue: 'logging-territory-read-warning',
        },
        loggingTerritoryUpdatedInfo: {
          routingKey: 'logging.territory.updated.info',
          queue: 'logging-territory-updated-info',
        },
        loggingTerritoryUpdatedCrit: {
          routingKey: 'logging.territory.updated.crit',
          queue: 'logging-territory-updated-crit',
        },
        loggingTerritoryHealthCrit: {
          routingKey: 'logging.territory.health.crit',
          queue: 'logging-territory-health-crit',
        },
        loggingUserCreatedInfo: {
          routingKey: 'logging.user.created.info',
          queue: 'logging-user-created-info',
        },
        loggingUserCreatedWarning: {
          routingKey: 'logging.user.created.warning',
          queue: 'logging-user-created-warning',
        },
        loggingUserCreatedCrit: {
          routingKey: 'logging.user.created.crit',
          queue: 'logging-user-created-crit',
        },
        loggingUserDeletedInfo: {
          routingKey: 'logging.user.deleted.info',
          queue: 'logging-user-deleted-info',
        },
        loggingUserDeletedCrit: {
          routingKey: 'logging.user.deleted.crit',
          queue: 'logging-user-deleted-crit',
        },
        loggingUserReadWarning: {
          routingKey: 'logging.user.read.warning',
          queue: 'logging-user-read-warning',
        },
        loggingUserUpdatedInfo: {
          routingKey: 'logging.user.updated.info',
          queue: 'logging-user-updated-info',
        },
        loggingUserUpdatedCrit: {
          routingKey: 'logging.user.updated.crit',
          queue: 'logging-user-updated-crit',
        },
        loggingUserHealthCrit: {
          routingKey: 'logging.user.health.crit',
          queue: 'logging-user-health-crit',
        },
      },
    }),
  }),
];

const providers: Provider[] = [
  {
    provide: MESSAGE_PUBLISHER,
    useClass: MessageBrokerPublisher,
  },
];

@Module({
  imports,
  providers,
  exports: [MESSAGE_PUBLISHER],
})
export class MessagerModule {}
